

class RankData:
    
    def __init__(data):
        pass
    
    def serialize(data, types):
        pass 
    
    def scanContext(data):
        pass
    
    
    def rankData(data):
        pass


import tensorflow as tf #machine learning library 
import numpy as np #tables transformations 
import scipy as sp #doing some equasions 


class ml:
    
    def __init__():
        
        search = tf.feature_column.numeric_column("search")
        result = tf.feature_column.numeric_column("result")
        
        
    
    def train():
        pass
    
    def analyzeData(var1, var2, var3):
        pass


# -*- coding: utf-8 -*-

import sys, pymysql, json
from termcolor import * #not yet used, but is here
from modules.sort import sortData #our code yeah
from modules.db import database
from urllib.parse import urlparse


global cur

try:	
	from access import db as data
except ImportError:
	print("You have not edited access.py file") 
 
try:
	db = pymysql.connect(
	        host=data[0],
	        user=data[1],
	        passwd=data[2],
	        db=data[3],
		autocommit=True)

	
	
	cur = db.cursor()
	database.createDatabase(cur)
	
except pymysql.MySQLError:
	exit("Lack of MySQL connection")
except pymysql.InternalError:
	exit("I don't know what have just happend")
except pymysql.NotSupportedError:
	exit("I don't know what have just happened")

def addURL(url, addr, json):		
	
	sql   = "INSERT INTO url (main_url, path, ip) VALUE (%s, %s, %s)"
	table = urlparse(url)
	
	if len(table.netloc) > 0:
		netloc = table.netloc
	else:
		netloc = None
		
	if len(table.path) > 0:
		path   = table.path
	else:	
		path   = None
		
	cur.execute(sql, (netloc, path, addr))
	
	if cur.rowcount == 1:
		print(colored(url, 'red')+": added")
	
	

def checkURL(url, addr, json):
	
	sql = "SELECT ip FROM url WHERE ip=%s"
	cur.execute(sql, (addr))
	res = cur.fetchone()
	if cur.rowcount == 0:
		addURL(url, addr, json)
	
		
	


# -*- coding: utf-8 -*- 

import socket, requests, validators, certifi
from tqdm import tqdm
from smart import checkURL
from modules.json import creatJSON
from modules.sort import sortData
from termcolor import colored
from bs4 import BeautifulSoup

#some init requests
socket.setdefaulttimeout(10)
requests.packages.urllib3.disable_warnings()

json  = creatJSON()
addr  = 0
skip  = ['127.0.0.1', '127.0.1.1', '0.0.0.0']

def scanIP(args):

    if args.fromto is not None:
        ft = args.fromto
    if args.skip is not None:
        s  = args.skip 
        
    if args.url == 'N':
        #scaning IP adress in ip range, without entry 69.59.196.211
        a = 69
        b = 59
        c = 196
        d = 211
        with tqdm(total= ((255-a)*(255-b)*(255-c)*(255-d) - len(skip)), desc="scanning") as bar:
            for num in range(a,255):
                for num2 in range(b,255):
                    for num3 in range(c,255):
                        for num4 in range(d,255):
                            global addr
                            addr = str(num)+"."+str(num2)+"."+str(num3)+"."+str(num4)
                            if not addr in skip:
                                parseURL(addr)
                                bar.set_description(desc="scanning: "+str(num)+"."+str(num2)+"."+str(num3)+"."+str(num4))
                                bar.update(1)
    elif validators.url(str(args.url)):
        scanDomain(str(args.url))
    else:
        pass




def lookup(addr):
    try:
        #look for better solution, because it does not work properly most of the time 
        return socket.gethostbyaddr(addr)
    except socket.herror:
        return None, None, None


def loadURL(url):

    global ssl 
    if not url.startswith("https://") and not url.startswith("http://"):
        url2 = "https://"+url        
    try:
        html = requests.get(url2, verify=certifi.where(), timeout=20)
        if html.status_code == 200:
            ssl = 1
            return html
        else: return 0
    except requests.exceptions.SSLError:
        html = requests.get("http://"+url, verify=False, timeout=20)
        if html.status_code == 200:
            ssl = 0
            return html
        else: return 0
    except requests.exceptions.ConnectionError:
        exit("It seems you lost internet connection")
    except  requests.exceptions.HTTPError:
        return 0


def scanDomain(url):
    html = loadURL(url)
    if html != 0:
        content = BeautifulSoup(html.text, 'html.parser')
        if content.title != None:
            title = content.title.text
            title = title.encode('utf-8')
            print(colored(title.decode(), "yellow"))

            for link in content.find_all('a'):
                url = link.get('href')
                if validators.url(str(url)):
                    #adding addition url addresses found on the particual webpage
                    pass
                else:
                    pass


            for meta in content.find_all('meta'):
                m = meta.get('meta')                                    

            texts = content.findAll(text=True)
            #There is something wrong with this part and I don't know what
            sortData.sort(texts)

        checkURL(url, addr, json)



def parseURL(addr):
    #Printing which ip address is being currently scanned 
    #print(colored(addr, 'green'))
    url, alias, addressList = lookup(addr) 
    if url != None:
        scanDomain(url)












# -*- coding: utf-8 -*- 
from .ranks import RankData
import re
import validators

class sortData:
    
    def __init__(self):
        pass
    
    
    def uniqueWords(text):
        words  = {}
        pass
    
    def addToCategory(word):
        
        categories = {'tech', 'faith', 'jesus', 'christ'}
        RankData.rankData(word)
        
    def sort(text):
        pass

    
        


import os
from setuptools import setup
from scan import version


setup(name='syrahsearch',
      version=version,
      description='Command-line search engine with some cool machine learning solutions.',
      url='https://github.com/syrahsearch/syrah',
      author='Kamil Boberek',
      packages=['modules', 'AI'],
      author_email='notimportant@protonmail.com',
      license='MIT',
      entry_points={
          'console_scripts': [
              'syrahsearch = scan:main'
          ]
      },      
      install_requires=[
          'validators',
          'tensorflow',
          'termcolor',
          'requests',
          'numpy',
          'scipy',
          'PyMySQL',
          'beautifulsoup4',
          'dropbox',
      ],      
      zip_safe=False      
)


#!/usr/bin/env python3.6
# -*- coding: utf-8 -*-

import sys, argparse, socket
from syrah import scanIP

version = "0.0.0.2.2"

def isConnection():
    try:
        host = socket.gethostbyname("www.google.com")
        s = socket.create_connection((host, 80), 2)
        return True
    except:
        pass
    return False 

def main(argv = None):
        
    parser = argparse.ArgumentParser(description='Scan website links and content', usage='Type your url link or type N to scan the whole web, yeah')
    parser.add_argument('--url', dest="url", type=str, help='url of website to scan', default='N', required=True)
    parser.add_argument('--search', dest="search", type=str, help='search a phrase you want to find in web')
    parser.add_argument('--version', action='version', help='print version of syrahsearch', version = version)
    parser.add_argument('--fromto', dest="fromto", type=int, help='depth of searching', required=False)
    parser.add_argument('--skip', dest="skip", type=str, help='skip some domains and ip addrss', required=False)

    args = parser.parse_args()
    
    #print(args.url)
    if args:
        scanIP(args)
    else:
        exit(0)
    
    
if __name__ == "__main__":
    
    if isConnection:
        main(sys.argv[1:])
    else:
        exit("You cannot run this script without internet connection")




import os
from pathlib import Path

try:
    from ..access import dbx
except ImportError:
    print("You've not edited your access file. You need dropbox access_token!")
    

def localStorage(json):
    path = Path('./var/analytics/analytics')
    if not path.is_file():
        f = open(path.absolute, "w+")
    
        

def createFile():

    if dbx[0] != 'access_token':
        
        import dropbox
        from dropbox.files import WriteMode
        from dropbox.exceptions import ApiError, AuthError
        import sys 
        
        try:
            dbox = dropbox.Dropbox(dbx[0])
        except:
            #connection error -> turn to local storage 
            localStorage()
        
        
        
    else:
        #turn to local storage 
        localStorage()